/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractscrollarea.sip"
#include <qabstractscrollarea.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qscrollbar.sip"
#include <qscrollbar.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 230 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 265 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractScrollArea.cpp"


class sipQAbstractScrollArea : public ::QAbstractScrollArea
{
public:
    sipQAbstractScrollArea(::QWidget*);
    virtual ~sipQAbstractScrollArea();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setupViewport(::QWidget*) SIP_OVERRIDE;
    void scrollContentsBy(int, int) SIP_OVERRIDE;
    bool viewportEvent(::QEvent*) SIP_OVERRIDE;
    ::QSize viewportSizeHint() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void initStyleOption(::QStyleOptionFrame*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractScrollArea(const sipQAbstractScrollArea &);
    sipQAbstractScrollArea &operator = (const sipQAbstractScrollArea &);

    char sipPyMethods[51];
};

sipQAbstractScrollArea::sipQAbstractScrollArea(::QWidget*a0): ::QAbstractScrollArea(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractScrollArea::~sipQAbstractScrollArea()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAbstractScrollArea::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QAbstractScrollArea);

    return ::QAbstractScrollArea::metaObject();
}

int sipQAbstractScrollArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAbstractScrollArea::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QAbstractScrollArea, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAbstractScrollArea::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QAbstractScrollArea, _clname, &sipCpp) ? sipCpp : ::QAbstractScrollArea::qt_metacast(_clname));
}

void sipQAbstractScrollArea::setupViewport(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_setupViewport);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::setupViewport(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::scrollContentsBy(int a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_scrollContentsBy);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::scrollContentsBy(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int);

    sipVH_QtWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAbstractScrollArea::viewportEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_viewportEvent);

    if (!sipMeth)
        return ::QAbstractScrollArea::viewportEvent(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQAbstractScrollArea::viewportSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewportSizeHint);

    if (!sipMeth)
        return ::QAbstractScrollArea::viewportSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractScrollArea::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainter* sipQAbstractScrollArea::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QAbstractScrollArea::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractScrollArea::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QAbstractScrollArea::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQAbstractScrollArea::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QAbstractScrollArea::hasHeightForWidth();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractScrollArea::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QAbstractScrollArea::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQAbstractScrollArea::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QAbstractScrollArea::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractScrollArea::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QAbstractScrollArea::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQAbstractScrollArea::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QAbstractScrollArea::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQAbstractScrollArea::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QAbstractScrollArea::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractScrollArea::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractScrollArea::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[40]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QAbstractScrollArea::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPaintEngine* sipQAbstractScrollArea::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QAbstractScrollArea::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQAbstractScrollArea::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QAbstractScrollArea::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractScrollArea::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAbstractScrollArea::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractScrollArea::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAbstractScrollArea::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstractScrollArea::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[46], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractScrollArea::initStyleOption(::QStyleOptionFrame*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[50]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QAbstractScrollArea::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionFrame*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAbstractScrollArea_verticalScrollBarPolicy, "verticalScrollBarPolicy(self) -> Qt.ScrollBarPolicy");

extern "C" {static PyObject *meth_QAbstractScrollArea_verticalScrollBarPolicy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_verticalScrollBarPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::Qt::ScrollBarPolicy sipRes;

            sipRes = sipCpp->verticalScrollBarPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_ScrollBarPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_verticalScrollBarPolicy, doc_QAbstractScrollArea_verticalScrollBarPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setVerticalScrollBarPolicy, "setVerticalScrollBarPolicy(self, a0: Qt.ScrollBarPolicy)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setVerticalScrollBarPolicy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setVerticalScrollBarPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::ScrollBarPolicy a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_Qt_ScrollBarPolicy, &a0))
        {
            sipCpp->setVerticalScrollBarPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setVerticalScrollBarPolicy, doc_QAbstractScrollArea_setVerticalScrollBarPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_verticalScrollBar, "verticalScrollBar(self) -> QScrollBar|None");

extern "C" {static PyObject *meth_QAbstractScrollArea_verticalScrollBar(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_verticalScrollBar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QScrollBar*sipRes;

            sipRes = sipCpp->verticalScrollBar();

            return sipConvertFromType(sipRes, sipType_QScrollBar, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_verticalScrollBar, doc_QAbstractScrollArea_verticalScrollBar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_horizontalScrollBarPolicy, "horizontalScrollBarPolicy(self) -> Qt.ScrollBarPolicy");

extern "C" {static PyObject *meth_QAbstractScrollArea_horizontalScrollBarPolicy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_horizontalScrollBarPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::Qt::ScrollBarPolicy sipRes;

            sipRes = sipCpp->horizontalScrollBarPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_ScrollBarPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_horizontalScrollBarPolicy, doc_QAbstractScrollArea_horizontalScrollBarPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setHorizontalScrollBarPolicy, "setHorizontalScrollBarPolicy(self, a0: Qt.ScrollBarPolicy)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setHorizontalScrollBarPolicy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setHorizontalScrollBarPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::ScrollBarPolicy a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_Qt_ScrollBarPolicy, &a0))
        {
            sipCpp->setHorizontalScrollBarPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setHorizontalScrollBarPolicy, doc_QAbstractScrollArea_setHorizontalScrollBarPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_horizontalScrollBar, "horizontalScrollBar(self) -> QScrollBar|None");

extern "C" {static PyObject *meth_QAbstractScrollArea_horizontalScrollBar(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_horizontalScrollBar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QScrollBar*sipRes;

            sipRes = sipCpp->horizontalScrollBar();

            return sipConvertFromType(sipRes, sipType_QScrollBar, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_horizontalScrollBar, doc_QAbstractScrollArea_horizontalScrollBar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_viewport, "viewport(self) -> QWidget|None");

extern "C" {static PyObject *meth_QAbstractScrollArea_viewport(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_viewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->viewport();

            return sipConvertFromType(sipRes, sipType_QWidget, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_viewport, doc_QAbstractScrollArea_viewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_maximumViewportSize, "maximumViewportSize(self) -> QSize");

extern "C" {static PyObject *meth_QAbstractScrollArea_maximumViewportSize(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_maximumViewportSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->maximumViewportSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_maximumViewportSize, doc_QAbstractScrollArea_maximumViewportSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_minimumSizeHint, "minimumSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QAbstractScrollArea_minimumSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_minimumSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QAbstractScrollArea::minimumSizeHint() : sipCpp->minimumSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_minimumSizeHint, doc_QAbstractScrollArea_minimumSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QAbstractScrollArea_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QAbstractScrollArea::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_sizeHint, doc_QAbstractScrollArea_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setViewportMargins, "setViewportMargins(self, left: int, top: int, right: int, bottom: int)\n"
"setViewportMargins(self, margins: QMargins)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setViewportMargins(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setViewportMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "piiii", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setViewportMargins(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QMargins* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QMargins, &a0))
        {
            sipCpp->setViewportMargins(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setViewportMargins, doc_QAbstractScrollArea_setViewportMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_viewportMargins, "viewportMargins(self) -> QMargins");

extern "C" {static PyObject *meth_QAbstractScrollArea_viewportMargins(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_viewportMargins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QMargins*sipRes;

            sipRes = new ::QMargins(sipCpp->viewportMargins());

            return sipConvertFromNewType(sipRes, sipType_QMargins, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_viewportMargins, doc_QAbstractScrollArea_viewportMargins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_viewportSizeHint, "viewportSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QAbstractScrollArea_viewportSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_viewportSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QAbstractScrollArea::viewportSizeHint() : sipCpp->viewportSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_viewportSizeHint, doc_QAbstractScrollArea_viewportSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_event, "event(self, a0: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QAbstractScrollArea_event(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_event, doc_QAbstractScrollArea_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_viewportEvent, "viewportEvent(self, a0: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QAbstractScrollArea_viewportEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_viewportEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::viewportEvent(a0) : sipCpp->viewportEvent(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_viewportEvent, doc_QAbstractScrollArea_viewportEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_resizeEvent, "resizeEvent(self, a0: QResizeEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_resizeEvent, doc_QAbstractScrollArea_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_paintEvent, "paintEvent(self, a0: QPaintEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_paintEvent, doc_QAbstractScrollArea_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_mousePressEvent, "mousePressEvent(self, a0: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_mousePressEvent, doc_QAbstractScrollArea_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_mouseReleaseEvent, "mouseReleaseEvent(self, a0: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_mouseReleaseEvent, doc_QAbstractScrollArea_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, a0: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_mouseDoubleClickEvent, doc_QAbstractScrollArea_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_mouseMoveEvent, "mouseMoveEvent(self, a0: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_mouseMoveEvent, doc_QAbstractScrollArea_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_wheelEvent, "wheelEvent(self, a0: QWheelEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_wheelEvent, doc_QAbstractScrollArea_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_contextMenuEvent, "contextMenuEvent(self, a0: QContextMenuEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QContextMenuEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_contextMenuEvent, doc_QAbstractScrollArea_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_dragEnterEvent, "dragEnterEvent(self, a0: QDragEnterEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_dragEnterEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_dragEnterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragEnterEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QDragEnterEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::dragEnterEvent(a0) : sipCpp->dragEnterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_dragEnterEvent, doc_QAbstractScrollArea_dragEnterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_dragMoveEvent, "dragMoveEvent(self, a0: QDragMoveEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_dragMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_dragMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragMoveEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QDragMoveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::dragMoveEvent(a0) : sipCpp->dragMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_dragMoveEvent, doc_QAbstractScrollArea_dragMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_dragLeaveEvent, "dragLeaveEvent(self, a0: QDragLeaveEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_dragLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_dragLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragLeaveEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QDragLeaveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::dragLeaveEvent(a0) : sipCpp->dragLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_dragLeaveEvent, doc_QAbstractScrollArea_dragLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_dropEvent, "dropEvent(self, a0: QDropEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDropEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_dropEvent, doc_QAbstractScrollArea_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_keyPressEvent, "keyPressEvent(self, a0: QKeyEvent|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_keyPressEvent, doc_QAbstractScrollArea_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_eventFilter, "eventFilter(self, a0: QObject|None, a1: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QAbstractScrollArea_eventFilter(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_eventFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        ::QEvent* a1;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QObject, &a0, sipType_QEvent, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::eventFilter(a0, a1) : sipCpp->eventFilter(a0, a1));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_eventFilter, doc_QAbstractScrollArea_eventFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_scrollContentsBy, "scrollContentsBy(self, dx: int, dy: int)");

extern "C" {static PyObject *meth_QAbstractScrollArea_scrollContentsBy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_scrollContentsBy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pii", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, &a0, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::scrollContentsBy(a0, a1) : sipCpp->scrollContentsBy(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_scrollContentsBy, doc_QAbstractScrollArea_scrollContentsBy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setVerticalScrollBar, "setVerticalScrollBar(self, scrollbar: QScrollBar|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setVerticalScrollBar(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setVerticalScrollBar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QScrollBar* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QScrollBar, &a0))
        {
            sipCpp->setVerticalScrollBar(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setVerticalScrollBar, doc_QAbstractScrollArea_setVerticalScrollBar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setHorizontalScrollBar, "setHorizontalScrollBar(self, scrollbar: QScrollBar|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setHorizontalScrollBar(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setHorizontalScrollBar(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QScrollBar* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QScrollBar, &a0))
        {
            sipCpp->setHorizontalScrollBar(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setHorizontalScrollBar, doc_QAbstractScrollArea_setHorizontalScrollBar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_cornerWidget, "cornerWidget(self) -> QWidget|None");

extern "C" {static PyObject *meth_QAbstractScrollArea_cornerWidget(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_cornerWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->cornerWidget();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_cornerWidget, doc_QAbstractScrollArea_cornerWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setCornerWidget, "setCornerWidget(self, widget: QWidget|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setCornerWidget(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setCornerWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QWidget, &a0))
        {
            sipCpp->setCornerWidget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setCornerWidget, doc_QAbstractScrollArea_setCornerWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_addScrollBarWidget, "addScrollBarWidget(self, widget: QWidget|None, alignment: Qt.AlignmentFlag)");

extern "C" {static PyObject *meth_QAbstractScrollArea_addScrollBarWidget(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_addScrollBarWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::Qt::Alignment* a1;
        int a1State = 0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:J1", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QWidget, &a0, sipType_QFlags_0100Qt_AlignmentFlag, &a1, &a1State))
        {
            sipCpp->addScrollBarWidget(a0, *a1);
            sipReleaseType(a1, sipType_QFlags_0100Qt_AlignmentFlag, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_addScrollBarWidget, doc_QAbstractScrollArea_addScrollBarWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_scrollBarWidgets, "scrollBarWidgets(self, alignment: Qt.AlignmentFlag) -> list[QWidget]");

extern "C" {static PyObject *meth_QAbstractScrollArea_scrollBarWidgets(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_scrollBarWidgets(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Alignment* a0;
        int a0State = 0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QFlags_0100Qt_AlignmentFlag, &a0, &a0State))
        {
            ::QWidgetList*sipRes;

            sipRes = new ::QWidgetList(sipCpp->scrollBarWidgets(*a0));
            sipReleaseType(a0, sipType_QFlags_0100Qt_AlignmentFlag, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0101QWidget, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_scrollBarWidgets, doc_QAbstractScrollArea_scrollBarWidgets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setViewport, "setViewport(self, widget: QWidget|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setViewport(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QWidget, &a0))
        {
            sipCpp->setViewport(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setViewport, doc_QAbstractScrollArea_setViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setupViewport, "setupViewport(self, viewport: QWidget|None)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setupViewport(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setupViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractScrollArea)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QWidget, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractScrollArea::setupViewport(a0) : sipCpp->setupViewport(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setupViewport, doc_QAbstractScrollArea_setupViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_sizeAdjustPolicy, "sizeAdjustPolicy(self) -> QAbstractScrollArea.SizeAdjustPolicy");

extern "C" {static PyObject *meth_QAbstractScrollArea_sizeAdjustPolicy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_sizeAdjustPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractScrollArea, &sipCpp))
        {
            ::QAbstractScrollArea::SizeAdjustPolicy sipRes;

            sipRes = sipCpp->sizeAdjustPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractScrollArea_SizeAdjustPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_sizeAdjustPolicy, doc_QAbstractScrollArea_sizeAdjustPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractScrollArea_setSizeAdjustPolicy, "setSizeAdjustPolicy(self, policy: QAbstractScrollArea.SizeAdjustPolicy)");

extern "C" {static PyObject *meth_QAbstractScrollArea_setSizeAdjustPolicy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractScrollArea_setSizeAdjustPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractScrollArea::SizeAdjustPolicy a0;
        ::QAbstractScrollArea *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractScrollArea, &sipCpp, sipType_QAbstractScrollArea_SizeAdjustPolicy, &a0))
        {
            sipCpp->setSizeAdjustPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractScrollArea, sipName_setSizeAdjustPolicy, doc_QAbstractScrollArea_setSizeAdjustPolicy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstractScrollArea(void *, const sipTypeDef *);}
static void *cast_QAbstractScrollArea(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAbstractScrollArea *sipCpp = reinterpret_cast< ::QAbstractScrollArea *>(sipCppV);

    if (targetType == sipType_QAbstractScrollArea)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QFrame)->ctd_cast(static_cast< ::QFrame *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractScrollArea(void *, int);}
static void release_QAbstractScrollArea(void *sipCppV, int)
{
    ::QAbstractScrollArea *sipCpp = reinterpret_cast< ::QAbstractScrollArea *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAbstractScrollArea(Py_ssize_t);}
static void *array_QAbstractScrollArea(Py_ssize_t sipNrElem)
{
    return new ::QAbstractScrollArea[sipNrElem];
}


extern "C" {static void array_delete_QAbstractScrollArea(void *);}
static void array_delete_QAbstractScrollArea(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAbstractScrollArea *>(sipCpp);
}


extern "C" {static void dealloc_QAbstractScrollArea(sipSimpleWrapper *);}
static void dealloc_QAbstractScrollArea(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractScrollArea *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractScrollArea(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractScrollArea(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractScrollArea(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAbstractScrollArea *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQAbstractScrollArea(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstractScrollArea[] = {{115, 255, 1}};


static PyMethodDef methods_QAbstractScrollArea[] = {
    {sipName_addScrollBarWidget, meth_QAbstractScrollArea_addScrollBarWidget, METH_VARARGS, doc_QAbstractScrollArea_addScrollBarWidget},
    {sipName_contextMenuEvent, meth_QAbstractScrollArea_contextMenuEvent, METH_VARARGS, doc_QAbstractScrollArea_contextMenuEvent},
    {sipName_cornerWidget, meth_QAbstractScrollArea_cornerWidget, METH_VARARGS, doc_QAbstractScrollArea_cornerWidget},
    {sipName_dragEnterEvent, meth_QAbstractScrollArea_dragEnterEvent, METH_VARARGS, doc_QAbstractScrollArea_dragEnterEvent},
    {sipName_dragLeaveEvent, meth_QAbstractScrollArea_dragLeaveEvent, METH_VARARGS, doc_QAbstractScrollArea_dragLeaveEvent},
    {sipName_dragMoveEvent, meth_QAbstractScrollArea_dragMoveEvent, METH_VARARGS, doc_QAbstractScrollArea_dragMoveEvent},
    {sipName_dropEvent, meth_QAbstractScrollArea_dropEvent, METH_VARARGS, doc_QAbstractScrollArea_dropEvent},
    {sipName_event, meth_QAbstractScrollArea_event, METH_VARARGS, doc_QAbstractScrollArea_event},
    {sipName_eventFilter, meth_QAbstractScrollArea_eventFilter, METH_VARARGS, doc_QAbstractScrollArea_eventFilter},
    {sipName_horizontalScrollBar, meth_QAbstractScrollArea_horizontalScrollBar, METH_VARARGS, doc_QAbstractScrollArea_horizontalScrollBar},
    {sipName_horizontalScrollBarPolicy, meth_QAbstractScrollArea_horizontalScrollBarPolicy, METH_VARARGS, doc_QAbstractScrollArea_horizontalScrollBarPolicy},
    {sipName_keyPressEvent, meth_QAbstractScrollArea_keyPressEvent, METH_VARARGS, doc_QAbstractScrollArea_keyPressEvent},
    {sipName_maximumViewportSize, meth_QAbstractScrollArea_maximumViewportSize, METH_VARARGS, doc_QAbstractScrollArea_maximumViewportSize},
    {sipName_minimumSizeHint, meth_QAbstractScrollArea_minimumSizeHint, METH_VARARGS, doc_QAbstractScrollArea_minimumSizeHint},
    {sipName_mouseDoubleClickEvent, meth_QAbstractScrollArea_mouseDoubleClickEvent, METH_VARARGS, doc_QAbstractScrollArea_mouseDoubleClickEvent},
    {sipName_mouseMoveEvent, meth_QAbstractScrollArea_mouseMoveEvent, METH_VARARGS, doc_QAbstractScrollArea_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QAbstractScrollArea_mousePressEvent, METH_VARARGS, doc_QAbstractScrollArea_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QAbstractScrollArea_mouseReleaseEvent, METH_VARARGS, doc_QAbstractScrollArea_mouseReleaseEvent},
    {sipName_paintEvent, meth_QAbstractScrollArea_paintEvent, METH_VARARGS, doc_QAbstractScrollArea_paintEvent},
    {sipName_resizeEvent, meth_QAbstractScrollArea_resizeEvent, METH_VARARGS, doc_QAbstractScrollArea_resizeEvent},
    {sipName_scrollBarWidgets, meth_QAbstractScrollArea_scrollBarWidgets, METH_VARARGS, doc_QAbstractScrollArea_scrollBarWidgets},
    {sipName_scrollContentsBy, meth_QAbstractScrollArea_scrollContentsBy, METH_VARARGS, doc_QAbstractScrollArea_scrollContentsBy},
    {sipName_setCornerWidget, meth_QAbstractScrollArea_setCornerWidget, METH_VARARGS, doc_QAbstractScrollArea_setCornerWidget},
    {sipName_setHorizontalScrollBar, meth_QAbstractScrollArea_setHorizontalScrollBar, METH_VARARGS, doc_QAbstractScrollArea_setHorizontalScrollBar},
    {sipName_setHorizontalScrollBarPolicy, meth_QAbstractScrollArea_setHorizontalScrollBarPolicy, METH_VARARGS, doc_QAbstractScrollArea_setHorizontalScrollBarPolicy},
    {sipName_setSizeAdjustPolicy, meth_QAbstractScrollArea_setSizeAdjustPolicy, METH_VARARGS, doc_QAbstractScrollArea_setSizeAdjustPolicy},
    {sipName_setVerticalScrollBar, meth_QAbstractScrollArea_setVerticalScrollBar, METH_VARARGS, doc_QAbstractScrollArea_setVerticalScrollBar},
    {sipName_setVerticalScrollBarPolicy, meth_QAbstractScrollArea_setVerticalScrollBarPolicy, METH_VARARGS, doc_QAbstractScrollArea_setVerticalScrollBarPolicy},
    {sipName_setViewport, meth_QAbstractScrollArea_setViewport, METH_VARARGS, doc_QAbstractScrollArea_setViewport},
    {sipName_setViewportMargins, meth_QAbstractScrollArea_setViewportMargins, METH_VARARGS, doc_QAbstractScrollArea_setViewportMargins},
    {sipName_setupViewport, meth_QAbstractScrollArea_setupViewport, METH_VARARGS, doc_QAbstractScrollArea_setupViewport},
    {sipName_sizeAdjustPolicy, meth_QAbstractScrollArea_sizeAdjustPolicy, METH_VARARGS, doc_QAbstractScrollArea_sizeAdjustPolicy},
    {sipName_sizeHint, meth_QAbstractScrollArea_sizeHint, METH_VARARGS, doc_QAbstractScrollArea_sizeHint},
    {sipName_verticalScrollBar, meth_QAbstractScrollArea_verticalScrollBar, METH_VARARGS, doc_QAbstractScrollArea_verticalScrollBar},
    {sipName_verticalScrollBarPolicy, meth_QAbstractScrollArea_verticalScrollBarPolicy, METH_VARARGS, doc_QAbstractScrollArea_verticalScrollBarPolicy},
    {sipName_viewport, meth_QAbstractScrollArea_viewport, METH_VARARGS, doc_QAbstractScrollArea_viewport},
    {sipName_viewportEvent, meth_QAbstractScrollArea_viewportEvent, METH_VARARGS, doc_QAbstractScrollArea_viewportEvent},
    {sipName_viewportMargins, meth_QAbstractScrollArea_viewportMargins, METH_VARARGS, doc_QAbstractScrollArea_viewportMargins},
    {sipName_viewportSizeHint, meth_QAbstractScrollArea_viewportSizeHint, METH_VARARGS, doc_QAbstractScrollArea_viewportSizeHint},
    {sipName_wheelEvent, meth_QAbstractScrollArea_wheelEvent, METH_VARARGS, doc_QAbstractScrollArea_wheelEvent}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAbstractScrollArea[] = {
    {sipName_AdjustIgnored, static_cast<int>(::QAbstractScrollArea::AdjustIgnored)},
    {sipName_AdjustToContentsOnFirstShow, static_cast<int>(::QAbstractScrollArea::AdjustToContentsOnFirstShow)},
    {sipName_AdjustToContents, static_cast<int>(::QAbstractScrollArea::AdjustToContents)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAbstractScrollArea, "\1QAbstractScrollArea(parent: QWidget|None = None)");


static pyqt6ClassPluginDef plugin_QAbstractScrollArea = {
    &::QAbstractScrollArea::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QAbstractScrollArea = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractScrollArea,
        SIP_NULLPTR,
        &plugin_QAbstractScrollArea,
    },
    {
        sipNameNr_QAbstractScrollArea,
        {0, 0, 1},
        40, methods_QAbstractScrollArea,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAbstractScrollArea, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractScrollArea,
    -1,
    -1,
    supers_QAbstractScrollArea,
    SIP_NULLPTR,
    init_type_QAbstractScrollArea,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractScrollArea,
    SIP_NULLPTR,
    array_QAbstractScrollArea,
    SIP_NULLPTR,
    release_QAbstractScrollArea,
    cast_QAbstractScrollArea,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAbstractScrollArea,
    sizeof (::QAbstractScrollArea),
};
